import type { VxeGridProps } from '#/adapter/vxe-table';

import { DictEnum } from '@vben/constants';

import { type FormSchemaGetter } from '#/adapter/form';
import { getDictOptions } from '#/utils/dict';
import { renderDict } from '#/utils/render';

export const querySchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    fieldName: 'equCode',
    label: '设备编号'
  },
  {
    component: 'Input',
    fieldName: 'equName',
    label: '设备名称'
  },
  {
    component: 'Input',
    fieldName: 'equAssetNo',
    label: '资产编号'
  },
  {
    component: 'Input',
    fieldName: 'location',
    label: '所在场所'
  },
  {
    component: 'Select',
    componentProps: {
      options: getDictOptions(DictEnum.SYS_EQU_STATUS)
    },
    fieldName: 'equStatus',
    label: '设备状态'
  }
  /* {
    component: 'Select',
    componentProps: {
      options: getDictOptions(DictEnum.EIMS_INVENTORY_DETAIL_STATU)
    },
    fieldName: 'status',
    label: '盘点明细'
  }*/
];

export const columns: VxeGridProps['columns'] = [
  { type: 'checkbox', width: 60, fixed: 'left' },
  {
    title: '盘点状态',
    field: 'status',
    sortable: true,
    minWidth: 100,
    fixed: 'left',
    slots: {
      default: ({ row }) => {
        return renderDict(row.status, DictEnum.EIMS_INVENTORY_DETAIL_STATU);
      }
    }
  },
  {
    title: '设备编号',
    field: 'equCode',
    minWidth: 120,
    fixed: 'left'
  },
  {
    title: '设备名称',
    field: 'equName',
    minWidth: 100
  },
  {
    title: '资产编号',
    field: 'equAssetNo',
    minWidth: 100
  },
  {
    title: '设备状态',
    field: 'equStatus',
    sortable: true,
    minWidth: 100,
    slots: {
      default: ({ row }) => {
        return renderDict(row.equStatus, DictEnum.SYS_EQU_STATUS);
      }
    }
  },
  {
    title: '使用部门',
    field: 'deptName',
    minWidth: 100
  },
  {
    title: '设备类型',
    field: 'equTypeName',
    minWidth: 100
  },
  {
    title: '设备位置',
    field: 'location',
    minWidth: 100
  },
  {
    title: '盘点人',
    field: 'inventoryUser',
    sortable: true,
    minWidth: 100
  },
  {
    field: 'action',
    fixed: 'right',
    slots: { default: 'action' },
    title: '操作',
    width: 200
  }
];

export const drawerSchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    fieldName: 'id'
  },
  {
    component: 'Input',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    fieldName: 'equId'
  },
  {
    component: 'Input',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    fieldName: 'inventoryId'
  },
  {
    component: 'RadioGroup',
    componentProps: {
      buttonStyle: 'solid',
      options: getDictOptions(DictEnum.EIMS_INVENTORY_DETAIL_STATU),
      optionType: 'button'
    },
    defaultValue: '0',
    fieldName: 'status',
    label: '状态'
  }
];
